******
Filter
******

.. _filter_api:

FilterExpression
================

.. currentmodule:: redisvl.query.filter

.. autoclass:: FilterExpression

Tag
===

.. currentmodule:: redisvl.query.filter

.. autoclass:: Tag
    :members:
    :special-members:
    :exclude-members: __hash__


Text
====


.. currentmodule:: redisvl.query.filter


.. autoclass:: Text
    :members:
    :special-members:
    :exclude-members: __hash__


Num
===


.. currentmodule:: redisvl.query.filter


.. autoclass:: Num
    :members:
    :special-members:
    :exclude-members: __hash__


Geo
===

.. currentmodule:: redisvl.query.filter

.. autoclass:: Geo
    :members:
    :special-members:
    :exclude-members: __hash__


GeoRadius
=========

.. currentmodule:: redisvl.query.filter

.. autoclass:: GeoRadius
    :members:
    :special-members:
    :exclude-members: __hash__
